@@ -62,6 +62,15 @@ fn try_get_mut_fail() {
     assert_eq!(cryo_mut.try_get_mut(), None);
 }
 
+#[test]
+fn unsize() {
+    let mut s = "hello".to_owned();
+    with_cryo(&mut *s, |cryo| {
+        assert_eq!(*cryo.read(), *"hello");
+        assert_eq!(*cryo.write(), *"hello");
+    });
+}
+
 #[test]
 fn block_on_drop() {
     with_cryo((&mut 42, lock_ty::<SyncLock>()), |cryo_mut| {
